@@ -92,7 +92,7 @@ class Contact(CommonContact):
     """
     def __init__(self, jid, account, name='', groups=[], show='', status='',
     sub='', ask='', resource='', priority=0, keyID='', client_caps=None,
-    our_chatstate=None, chatstate=None, last_status_time=None, msg_id=None,
+    our_chatstate=None, chatstate=None, last_status_time=None, msg_log_id=None,
     last_activity_time=None):
 
         CommonContact.__init__(self, jid, account, resource, show, status, name,
@@ -106,7 +106,7 @@ class Contact(CommonContact):
 
         self.priority = priority
         self.keyID = keyID
-        self.msg_id = msg_id
+        self.msg_log_id = msg_log_id
         self.last_status_time = last_status_time
         self.last_activity_time = last_activity_time
 
@@ -836,6 +836,8 @@ class MetacontactManager():
             # we want one nearby_family per account
             nearby_family = [data for data in family if account == data['account']]
 
+        if not nearby_family:
+            return (None, None, None)
         big_brother_data = self._get_metacontacts_big_brother(nearby_family)
         big_brother_jid = big_brother_data['jid']
         big_brother_account = big_brother_data['account']
