@@ -96,7 +96,7 @@ demandimport.ignore += ['gobject._gobject', 'libasyncns', 'i18n',
     'logging.NullHandler', 'dbus.service', 'OpenSSL.SSL', 'OpenSSL.crypto',
     'common.sleepy', 'DLFCN', 'dl', 'xml.sax', 'xml.sax.handler', 'ic',
     'Crypto.PublicKey', 'IPython', 'contextlib', 'imp', 'gst.interfaces',
-    'monotonic', 'gtkexcepthook']
+    'libxml2', 'libxml2mod', 'monotonic', 'gtkexcepthook', 'google.protobuf']
 
 if os.name == 'nt':
     import locale
